==> zio-aws-elastictranscoder_3-5.17.124.2-sources.jar: zio/aws/elastictranscoder/model/UpdatePipelineNotificationsResponse.scala <==
package zio.aws.elastictranscoder.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class UpdatePipelineNotificationsResponse(
    pipeline: Option[zio.aws.elastictranscoder.model.Pipeline] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.elastictranscoder.model.UpdatePipelineNotificationsResponse = {
    import UpdatePipelineNotificationsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.elastictranscoder.model.UpdatePipelineNotificationsResponse
      .builder()
      .optionallyWith(pipeline.map(value => value.buildAwsValue()))(_.pipeline)
      .build()
  }
  def asReadOnly
      : zio.aws.elastictranscoder.model.UpdatePipelineNotificationsResponse.ReadOnly =
    zio.aws.elastictranscoder.model.UpdatePipelineNotificationsResponse
      .wrap(buildAwsValue())
}
object UpdatePipelineNotificationsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.elastictranscoder.model.UpdatePipelineNotificationsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.elastictranscoder.model.UpdatePipelineNotificationsResponse =
      zio.aws.elastictranscoder.model.UpdatePipelineNotificationsResponse(
        pipeline.map(value => value.asEditable)
      )
    def pipeline: Option[zio.aws.elastictranscoder.model.Pipeline.ReadOnly]
    def getPipeline: ZIO[
      Any,
      AwsError,
      zio.aws.elastictranscoder.model.Pipeline.ReadOnly
    ] = AwsError.unwrapOptionField("pipeline", pipeline)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.elastictranscoder.model.UpdatePipelineNotificationsResponse
  ) extends zio.aws.elastictranscoder.model.UpdatePipelineNotificationsResponse.ReadOnly {
    override val pipeline
        : Option[zio.aws.elastictranscoder.model.Pipeline.ReadOnly] = scala
      .Option(impl.pipeline())
      .map(value => zio.aws.elastictranscoder.model.Pipeline.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.elastictranscoder.model.UpdatePipelineNotificationsResponse
  ): zio.aws.elastictranscoder.model.UpdatePipelineNotificationsResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-elastictranscoder_3-6.20.74.2-sources.jar: zio/aws/elastictranscoder/model/UpdatePipelineNotificationsResponse.scala <==
package zio.aws.elastictranscoder.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class UpdatePipelineNotificationsResponse(
    pipeline: Optional[zio.aws.elastictranscoder.model.Pipeline] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.elastictranscoder.model.UpdatePipelineNotificationsResponse = {
    import UpdatePipelineNotificationsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.elastictranscoder.model.UpdatePipelineNotificationsResponse
      .builder()
      .optionallyWith(pipeline.map(value => value.buildAwsValue()))(_.pipeline)
      .build()
  }
  def asReadOnly
      : zio.aws.elastictranscoder.model.UpdatePipelineNotificationsResponse.ReadOnly =
    zio.aws.elastictranscoder.model.UpdatePipelineNotificationsResponse
      .wrap(buildAwsValue())
}
object UpdatePipelineNotificationsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.elastictranscoder.model.UpdatePipelineNotificationsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.elastictranscoder.model.UpdatePipelineNotificationsResponse =
      zio.aws.elastictranscoder.model.UpdatePipelineNotificationsResponse(
        pipeline.map(value => value.asEditable)
      )
    def pipeline: Optional[zio.aws.elastictranscoder.model.Pipeline.ReadOnly]
    def getPipeline: ZIO[
      Any,
      AwsError,
      zio.aws.elastictranscoder.model.Pipeline.ReadOnly
    ] = AwsError.unwrapOptionField("pipeline", pipeline)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.elastictranscoder.model.UpdatePipelineNotificationsResponse
  ) extends zio.aws.elastictranscoder.model.UpdatePipelineNotificationsResponse.ReadOnly {
    override val pipeline
        : Optional[zio.aws.elastictranscoder.model.Pipeline.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.pipeline())
        .map(value => zio.aws.elastictranscoder.model.Pipeline.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.elastictranscoder.model.UpdatePipelineNotificationsResponse
  ): zio.aws.elastictranscoder.model.UpdatePipelineNotificationsResponse.ReadOnly =
    new Wrapper(impl)
}
